==> mars-common-2.2.1.3-Release-sources.jar: com/bizunited/platform/mars/service/RuleTemplateGroupService.java <==
package com.bizunited.platform.mars.service;

import com.bizunited.platform.core.annotations.ServiceMethodParam;
import com.bizunited.platform.mars.entity.RuleTemplateGroupEntity;

import java.lang.String;
import java.util.List;
import java.util.Set;

/**
 * RuleTemplateGroupEntity业务模型的服务层接口定义
 * @author saturn
 */
public interface RuleTemplateGroupService { 
  /**
   * 创建一个新的RuleTemplateGroupEntity模型对象（包括了可能的第三方系统调用、复杂逻辑处理等）
   */
  public List<RuleTemplateGroupEntity> create(Set<RuleTemplateGroupEntity> ruleTemplateGroupEntities);
  /**
   * 创建一个新的StudentEntity模型对象
   * 该代码由satrun骨架生成，默认不包括任何可能第三方系统调用、任何复杂逻辑处理等，主要应用场景为前端表单数据的暂存功能</br>
   * 该方法与本接口中的updateFrom方法呼应
   */
  public RuleTemplateGroupEntity createForm(RuleTemplateGroupEntity ruleTemplateGroupEntity);
  /**
   * 更新一个已有的RuleTemplateGroupEntity模型对象，其主键属性必须有值(1.1.4-release版本调整)。
   * 这个方法实际上一共分为三个步骤（默认）：</br>
   * 1、调用updateValidation方法完成表单数据更新前的验证</br>
   * 2、调用updateForm方法完成表单数据的更新</br>
   * 3、完成开发人员自行在本update方法中书写的，进行第三方系统调用（或特殊处理过程）的执行。</br>
   * 这样做的目的，实际上是为了保证updateForm方法中纯粹是处理表单数据的，在数据恢复表单引擎默认调用updateForm方法时，不会影响任何第三方业务数据
   * （当然，如果系统有特别要求，可由开发人员自行完成代码逻辑调整）
   */
  public List<RuleTemplateGroupEntity>  update(Set<RuleTemplateGroupEntity> ruleTemplateGroupEntities);
  /**
   * 该方法只用于处理业务表单信息，包括了主业务模型、其下的关联模型、分组信息和明细细信息等
   * 该方法非常重要，因为如果进行静态表单的数据恢复，那么表单引擎将默认调用主业务模型（服务层）的这个方法。</br>
   * 这样一来保证了数据恢复时，不会涉及任何第三方系统的调用（当然，如果开发人员需要涉及的，可以自行进行修改）
   */
  public RuleTemplateGroupEntity updateForm(RuleTemplateGroupEntity ruleTemplateGroupEntity);
  /**
   * 按照主键进行详情查询（包括关联信息）
   * @param id 主键
   */
  public RuleTemplateGroupEntity findDetailsById(@ServiceMethodParam(name="id") String id);
  /**
   * 按照RuleTemplateGroupEntity的主键编号，查询指定的数据信息（不包括任何关联信息）
   * @param id 主键
   * */
  public RuleTemplateGroupEntity findById(String id);
  /**
   *  按照主键进行信息的真删除 
   * @param id 主键 
   */
  public void deleteById(String id);
  /**
   * 按照分组编号编号进行查询
   * @param code 分组编号编号
   */
  public RuleTemplateGroupEntity findByCode(@ServiceMethodParam(name="code") String code);
  /**
   * 按照分组的状态情况进行查询，并按照分类+名字的方式进行排序（只包括基本信息）
   * @param groupStatus 如果不传入，表示查询所有信息，并按照一直的排序规则进行排序
   * @return
   */
  public Set<RuleTemplateGroupEntity> findByGroupStatus(Integer groupStatus);
  /**
   * 按照分组的类型进行查询，并按照分类+名字的方式进行排序（只包括基本信息）
   * @param type 1:判定组件、2、逻辑组件、3、锁组件，4、开始组件、5、结束组件、6、异常组件
   * @return
   */
  public Set<RuleTemplateGroupEntity> findByType(Integer type);
}

==> mars-common-2.2.1.50-Release-sources.jar: com/bizunited/platform/mars/service/RuleTemplateGroupService.java <==
package com.bizunited.platform.mars.service;

import com.bizunited.platform.core.annotations.ServiceMethodParam;
import com.bizunited.platform.mars.entity.RuleTemplateGroupEntity;

import java.lang.String;
import java.util.List;
import java.util.Set;

/**
 * RuleTemplateGroupEntity业务模型的服务层接口定义
 * @author saturn
 */
public interface RuleTemplateGroupService { 
  /**
   * 创建一个新的RuleTemplateGroupEntity模型对象（包括了可能的第三方系统调用、复杂逻辑处理等）
   */
  public List<RuleTemplateGroupEntity> create(Set<RuleTemplateGroupEntity> ruleTemplateGroupEntities);
  /**
   * 创建一个新的StudentEntity模型对象
   * 该代码由satrun骨架生成，默认不包括任何可能第三方系统调用、任何复杂逻辑处理等，主要应用场景为前端表单数据的暂存功能</br>
   * 该方法与本接口中的updateFrom方法呼应
   */
  public RuleTemplateGroupEntity createForm(RuleTemplateGroupEntity ruleTemplateGroupEntity);
  /**
   * 更新一个已有的RuleTemplateGroupEntity模型对象，其主键属性必须有值(1.1.4-release版本调整)。
   * 这个方法实际上一共分为三个步骤（默认）：</br>
   * 1、调用updateValidation方法完成表单数据更新前的验证</br>
   * 2、调用updateForm方法完成表单数据的更新</br>
   * 3、完成开发人员自行在本update方法中书写的，进行第三方系统调用（或特殊处理过程）的执行。</br>
   * 这样做的目的，实际上是为了保证updateForm方法中纯粹是处理表单数据的，在数据恢复表单引擎默认调用updateForm方法时，不会影响任何第三方业务数据
   * （当然，如果系统有特别要求，可由开发人员自行完成代码逻辑调整）
   */
  public List<RuleTemplateGroupEntity>  update(Set<RuleTemplateGroupEntity> ruleTemplateGroupEntities);
  /**
   * 该方法只用于处理业务表单信息，包括了主业务模型、其下的关联模型、分组信息和明细细信息等
   * 该方法非常重要，因为如果进行静态表单的数据恢复，那么表单引擎将默认调用主业务模型（服务层）的这个方法。</br>
   * 这样一来保证了数据恢复时，不会涉及任何第三方系统的调用（当然，如果开发人员需要涉及的，可以自行进行修改）
   */
  public RuleTemplateGroupEntity updateForm(RuleTemplateGroupEntity ruleTemplateGroupEntity);
  /**
   * 按照主键进行详情查询（包括关联信息）
   * @param id 主键
   */
  public RuleTemplateGroupEntity findDetailsById(@ServiceMethodParam(name="id") String id);
  /**
   * 按照RuleTemplateGroupEntity的主键编号，查询指定的数据信息（不包括任何关联信息）
   * @param id 主键
   * */
  public RuleTemplateGroupEntity findById(String id);
  /**
   *  按照主键进行信息的真删除 
   * @param id 主键 
   */
  public void deleteById(String id);
  /**
   * 按照分组编号编号进行查询
   * @param code 分组编号编号
   */
  public RuleTemplateGroupEntity findByCode(@ServiceMethodParam(name="code") String code);
  /**
   * 按照分组的状态情况进行查询，并按照分类+名字的方式进行排序（只包括基本信息）
   * @param groupStatus 如果不传入，表示查询所有信息，并按照一直的排序规则进行排序
   * @return
   */
  public Set<RuleTemplateGroupEntity> findByGroupStatus(Integer groupStatus);
  /**
   * 按照分组的类型和分组状态进行查询，并按照分类+名字的方式进行排序（只包括基本信息）
   * @param type 1:判定组件、2、逻辑组件、3、锁组件，4、开始组件、5、结束组件、6、异常组件
   * @param groupStatus 指定的分组状态 1：正常；其他值：不正常（该参数可以不传入）
   * @return 
   */
  public Set<RuleTemplateGroupEntity> findByTypeAndGroupStatus(Integer type , Integer groupStatus);
}
